@@ -18,21 +18,21 @@
 #include "bits/h_desat"
 
 
-#define GAMW 664
-#define GAMH 518
+#define GAMW (664 * dpiMult)
+#define GAMH (518 * dpiMult)
 
-#define GAMbutF 386
+#define GAMbutF (386 * dpiMult)
 
-#define CMAPX  10
-#define CMAPY  17
-#define CMAPCW 12
-#define CMAPCH  9
+#define CMAPX  (10 * dpiMult)
+#define CMAPY  (17 * dpiMult)
+#define CMAPCW (12 * dpiMult)
+#define CMAPCH ( 9 * dpiMult)
 #define CMAPW  (CMAPCW * 16)
 #define CMAPH  (CMAPCH * 16)
 
 #define MAXUNDO 32
 
-#define BUTTH   23
+#define BUTTH   (23 * dpiMult)
 #define N_HMAP   6     /* # of Hue modification remappings */
 
 #define N_HDBUTT 5
@@ -57,7 +57,7 @@
 #define HD_BUTTS  0x80
 #define HD_ALL   (HD_FRAME | HD_HANDS | HD_DIR | HD_VALS | HD_TITLE | HD_BUTTS)
 
-#define HD_RADIUS 30   /* radius of bounding circle of HDIALs */
+#define HD_RADIUS (30 * dpiMult)   /* radius of bounding circle of HDIALs */
 
 #define DEG2RAD (3.14159 / 180.0)
 #define RAD2DEG (180.0 / 3.14159)
@@ -170,16 +170,16 @@ static void build_hremap     PARM((void));
 
 
 
-#define CMAPF_WIDE 212
-#define CMAPF_HIGH 322
-#define BUTF_WIDE  212
-#define BUTF_HIGH   96
-#define MODF_WIDE  212
-#define MODF_HIGH   70
-#define HSVF_WIDE  205
-#define HSVF_HIGH  500
-#define RGBF_WIDE  185
-#define RGBF_HIGH  500
+#define CMAPF_WIDE (212 * dpiMult)
+#define CMAPF_HIGH (322 * dpiMult)
+#define BUTF_WIDE  (212 * dpiMult)
+#define BUTF_HIGH  ( 96 * dpiMult)
+#define MODF_WIDE  (212 * dpiMult)
+#define MODF_HIGH  ( 70 * dpiMult)
+#define HSVF_WIDE  (205 * dpiMult)
+#define HSVF_HIGH  (500 * dpiMult)
+#define RGBF_WIDE  (185 * dpiMult)
+#define RGBF_HIGH  (500 * dpiMult)
 
 
 #undef TIMING_TEST
@@ -190,8 +190,7 @@ static void build_hremap     PARM((void));
 
 
 /***************************/
-static void printUTime(str)
-     const char *str;
+static void printUTime(const char *str)
 {
 #ifdef TIMING_TEST
   int i;
@@ -200,32 +199,31 @@ static void printUTime(str)
   i = getrusage(RUSAGE_SELF, &ru);
   fprintf(stderr,"%s: utime = %ld.%ld seconds\n",
 	    str, ru.ru_utime.tv_sec, ru.ru_utime.tv_usec);
+#else
+  XV_UNUSED(str);
 #endif
 }
 
 
 
 /***************************************************/
-void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
-     const char *geom;
-     double      gam, rgam, ggam, bgam;
-     int         defpreset;
+void CreateGam(const char *geom, double gam, double rgam, double ggam, double bgam, int defpreset)
 {
   XSetWindowAttributes xswa;
 
   gamW = CreateWindow("xv color editor", "XVcedit", geom,
-		      GAMW, GAMH, infofg,infobg, 0);
+		      GAMW, GAMH, infofg,infobg, FALSE);
   if (!gamW) FatalError("can't create cedit window!");
 
-  cmapF = XCreateSimpleWindow(theDisp,gamW, 10,   8,CMAPF_WIDE,CMAPF_HIGH,
+  cmapF = XCreateSimpleWindow(theDisp,gamW,  10*dpiMult,   8*dpiMult,CMAPF_WIDE,CMAPF_HIGH,
 			      1,infofg,infobg);
-  butF  = XCreateSimpleWindow(theDisp,gamW, 10, 336,BUTF_WIDE,BUTF_HIGH,
+  butF  = XCreateSimpleWindow(theDisp,gamW,  10*dpiMult, 336*dpiMult,BUTF_WIDE,BUTF_HIGH,
 			      1,infofg,infobg);
-  modF  = XCreateSimpleWindow(theDisp,gamW, 10, 438,MODF_WIDE,MODF_HIGH,
+  modF  = XCreateSimpleWindow(theDisp,gamW,  10*dpiMult, 438*dpiMult,MODF_WIDE,MODF_HIGH,
 			      1,infofg,infobg);
-  hsvF  = XCreateSimpleWindow(theDisp,gamW, 242,  8,HSVF_WIDE,HSVF_HIGH,
+  hsvF  = XCreateSimpleWindow(theDisp,gamW, 242*dpiMult,   8*dpiMult,HSVF_WIDE,HSVF_HIGH,
 			      1,infofg,infobg);
-  rgbF  = XCreateSimpleWindow(theDisp,gamW, 467,  8,RGBF_WIDE,RGBF_HIGH,
+  rgbF  = XCreateSimpleWindow(theDisp,gamW, 467*dpiMult,   8*dpiMult,RGBF_WIDE,RGBF_HIGH,
 			      1,infofg,infobg);
 
   if (!cmapF || !butF || !modF || !hsvF || !rgbF)
@@ -252,25 +250,25 @@ void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
   /********** COLORMAP editing doo-wahs ***********/
 
 
-  BTCreate(&gbut[G_BCOLUNDO], cmapF, 5, 165, 66, BUTTH,
+  BTCreate(&gbut[G_BCOLUNDO], cmapF, 5 * dpiMult, 165 * dpiMult, 66 * dpiMult, BUTTH,
 	   "ColUndo", infofg, infobg, hicol, locol);
-  BTCreate(&gbut[G_BCOLREV], cmapF,  5 + 66 + 1, 165, 67, BUTTH,
+  BTCreate(&gbut[G_BCOLREV], cmapF,  (5 + 66 + 1) * dpiMult, 165 * dpiMult, 67 * dpiMult, BUTTH,
 	   "Revert", infofg, infobg, hicol, locol);
-  BTCreate(&gbut[G_BHSVRGB], cmapF,  5+66+67+2,  165, 66, BUTTH,
+  BTCreate(&gbut[G_BHSVRGB], cmapF,  (5 + 66 + 67 + 2) * dpiMult,  165 * dpiMult, 66 * dpiMult, BUTTH,
 	   "RGB/HSV", infofg, infobg, hicol, locol);
 
-  BTCreate(&gbut[G_BMONO], cmapF,    5, 189, 66, BUTTH,
+  BTCreate(&gbut[G_BMONO], cmapF,    5 * dpiMult, 189 * dpiMult, 66 * dpiMult, BUTTH,
 	   "Grey", infofg, infobg, hicol, locol);
-  BTCreate(&gbut[G_BRV],   cmapF,    5 + 66 + 1, 189, 67, BUTTH,
+  BTCreate(&gbut[G_BRV],   cmapF,    (5 + 66 + 1) * dpiMult, 189 * dpiMult, 67 * dpiMult, BUTTH,
 	   "RevVid", infofg, infobg, hicol, locol);
-  BTCreate(&gbut[G_BRNDCOL], cmapF,  5 + 66 + 67 + 2, 189, 66, BUTTH,
+  BTCreate(&gbut[G_BRNDCOL], cmapF,  (5 + 66 + 67 + 2) * dpiMult, 189 * dpiMult, 66 * dpiMult, BUTTH,
 	   "Random", infofg, infobg, hicol, locol);
 
-  DCreate(&rhDial, cmapF, 5, 215, 66, 100,   0.0, 360.0, 180.0, 1.0, 5.0,
+  DCreate(&rhDial, cmapF, 5 * dpiMult, 215 * dpiMult, 66 * dpiMult, 100 * dpiMult,   0.0, 360.0, 180.0, 1.0, 5.0,
 	  infofg, infobg, hicol, locol, "Hue", NULL);
-  DCreate(&gsDial, cmapF, 72, 215, 66, 100,  0.0, 360.0, 180.0, 1.0, 5.0,
+  DCreate(&gsDial, cmapF, 72 * dpiMult, 215 * dpiMult, 66 * dpiMult, 100 * dpiMult,  0.0, 360.0, 180.0, 1.0, 5.0,
 	  infofg, infobg, hicol, locol, "Sat.", NULL);
-  DCreate(&bvDial, cmapF, 139, 215, 66, 100, 0.0, 360.0, 180.0, 1.0, 5.0,
+  DCreate(&bvDial, cmapF, 139 * dpiMult, 215 * dpiMult, 66 * dpiMult, 100 * dpiMult, 0.0, 360.0, 180.0, 1.0, 5.0,
 	  infofg, infobg, hicol, locol, "Value", NULL);
 
   rhDial.drawobj = gsDial.drawobj = bvDial.drawobj = dragEditColor;
@@ -279,7 +277,7 @@ void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
   /*********** CONTROL BUTTONS ***********/
 
 /* positioning constants for buttons.  (arranged as 4x4 grid...) */
-#define BXSPACE 53
+#define BXSPACE (53 * dpiMult)
 #define BYSPACE (BUTTH+1)
 
 #define BX0 0
@@ -292,44 +290,44 @@ void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
 #define BY2 (BY0 + BYSPACE*2)
 #define BY3 (BY0 + BYSPACE*3)
 
-  BTCreate(&gbut[G_BAPPLY],  butF, BX0,BY0, 52,BUTTH,"Apply",
+  BTCreate(&gbut[G_BAPPLY],  butF, BX0,BY0, 52 * dpiMult,BUTTH,"Apply",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BNOGAM],  butF, BX0,BY1, 52,BUTTH,"NoMod",
+  BTCreate(&gbut[G_BNOGAM],  butF, BX0,BY1, 52 * dpiMult,BUTTH,"NoMod",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BMAXCONT],butF, BX0,BY2, 52,BUTTH,"Norm",
+  BTCreate(&gbut[G_BMAXCONT],butF, BX0,BY2, 52 * dpiMult,BUTTH,"Norm",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BHISTEQ], butF, BX0,BY3, 52,BUTTH,"HistEq",
+  BTCreate(&gbut[G_BHISTEQ], butF, BX0,BY3, 52 * dpiMult,BUTTH,"HistEq",
 	   infofg,infobg,hicol,locol);
 
-  BTCreate(&gbut[G_BUP_BR],butF, BX1,BY0, 52,BUTTH,"Brite",
+  BTCreate(&gbut[G_BUP_BR],butF, BX1,BY0, 52 * dpiMult,BUTTH,"Brite",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BDN_BR],butF, BX1,BY1, 52,BUTTH,"Dim",
+  BTCreate(&gbut[G_BDN_BR],butF, BX1,BY1, 52 * dpiMult,BUTTH,"Dim",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BUP_CN],butF, BX1,BY2, 52,BUTTH,"Sharp",
+  BTCreate(&gbut[G_BUP_CN],butF, BX1,BY2, 52 * dpiMult,BUTTH,"Sharp",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BDN_CN],butF, BX1,BY3, 52,BUTTH,"Dull",
+  BTCreate(&gbut[G_BDN_CN],butF, BX1,BY3, 52 * dpiMult,BUTTH,"Dull",
 	   infofg,infobg,hicol,locol);
 
-  BTCreate(&gbut[G_BRESET],butF, BX2,   BY0, 52,BUTTH,"Reset",
+  BTCreate(&gbut[G_BRESET],butF, BX2,   BY0, 52 * dpiMult,BUTTH,"Reset",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_B1],    butF, BX2,   BY1, 25,BUTTH,"1",
+  BTCreate(&gbut[G_B1],    butF, BX2,   BY1, 25 * dpiMult,BUTTH,"1",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_B2],    butF, BX2+26,BY1, 26,BUTTH,"2",
+  BTCreate(&gbut[G_B2],    butF, BX2+26*dpiMult,BY1, 26 * dpiMult,BUTTH,"2",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_B3],    butF, BX2,   BY2, 25,BUTTH,"3",
+  BTCreate(&gbut[G_B3],    butF, BX2,   BY2, 25 * dpiMult,BUTTH,"3",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_B4],    butF, BX2+26,BY2, 26,BUTTH,"4",
+  BTCreate(&gbut[G_B4],    butF, BX2+26*dpiMult,BY2, 26 * dpiMult,BUTTH,"4",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BSET],  butF, BX2,   BY3, 52,BUTTH,"Set",
+  BTCreate(&gbut[G_BSET],  butF, BX2,   BY3, 52 * dpiMult,BUTTH,"Set",
 	   infofg,infobg,hicol,locol);
 
-  BTCreate(&gbut[G_BUNDO], butF, BX3, BY0, 52,BUTTH,"Undo",
+  BTCreate(&gbut[G_BUNDO], butF, BX3, BY0, 52 * dpiMult,BUTTH,"Undo",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BREDO], butF, BX3, BY1, 52,BUTTH,"Redo",
+  BTCreate(&gbut[G_BREDO], butF, BX3, BY1, 52 * dpiMult,BUTTH,"Redo",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BGETRES],butF,BX3, BY2, 52,BUTTH,"CutRes",
+  BTCreate(&gbut[G_BGETRES],butF,BX3, BY2, 52 * dpiMult,BUTTH,"CutRes",
 	   infofg,infobg,hicol,locol);
-  BTCreate(&gbut[G_BCLOSE],butF, BX3, BY3, 52,BUTTH,"Close",
+  BTCreate(&gbut[G_BCLOSE],butF, BX3, BY3, 52 * dpiMult,BUTTH,"Close",
 	   infofg,infobg,hicol,locol);
 
 
@@ -337,13 +335,13 @@ void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
   gbut[G_BUNDO].active = 0;
   gbut[G_BREDO].active = 0;
 
-  CBCreate(&enabCB, modF,2,2,     "Display with HSV/RGB mods.",
+  CBCreate(&enabCB, modF,2 * dpiMult,2 * dpiMult,     "Display with HSV/RGB mods.",
 	   infofg,infobg,hicol,locol);
-  CBCreate(&autoCB, modF,2,2+17,  "Auto-apply HSV/RGB mods.",
+  CBCreate(&autoCB, modF,2 * dpiMult,(2+17) * dpiMult,  "Auto-apply HSV/RGB mods.",
 	   infofg,infobg,hicol,locol);
-  CBCreate(&dragCB, modF,2,2+17*2,"Auto-apply while dragging.",
+  CBCreate(&dragCB, modF,2 * dpiMult,(2+17*2) * dpiMult,"Auto-apply while dragging.",
 	   infofg,infobg,hicol,locol);
-  CBCreate(&resetCB,modF,2,2+17*3,"Auto-reset on new image.",
+  CBCreate(&resetCB,modF,2 * dpiMult,(2+17*3) * dpiMult,"Auto-reset on new image.",
 	   infofg,infobg,hicol,locol);
 
   enabCB.val = autoCB.val = resetCB.val = dragCB.val = 1;
@@ -353,30 +351,30 @@ void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
   /************ HSV editing doo-wahs **************/
 
 
-  HDCreate(&srcHD, hsvF,  52, 65, 1, 0, 30, 0, "From", infofg, infobg);
-  HDCreate(&dstHD, hsvF, 154, 65, 1, 0, 30, 0, "To",   infofg, infobg);
+  HDCreate(&srcHD, hsvF,  52 * dpiMult, 65 * dpiMult, 1, 0, 30, 0, "From", infofg, infobg);
+  HDCreate(&dstHD, hsvF, 154 * dpiMult, 65 * dpiMult, 1, 0, 30, 0, "To",   infofg, infobg);
 
-  HDCreate(&whtHD, hsvF,  50,243, 0, 0,  0, 0, "White",infofg, infobg);
+  HDCreate(&whtHD, hsvF,  50 * dpiMult,243 * dpiMult, 0, 0,  0, 0, "White",infofg, infobg);
 
   srcHD.drawobj = dstHD.drawobj = whtHD.drawobj = dragHueDial;
 
-  DCreate(&satDial, hsvF, 100, 199, 100, 121, -100.0, 100.0, 0.0, 1.0, 5.0,
+  DCreate(&satDial, hsvF, 100 * dpiMult, 199 * dpiMult, 100 * dpiMult, 121 * dpiMult, -100.0, 100.0, 0.0, 1.0, 5.0,
 	   infofg, infobg,hicol,locol, "Saturation", "%");
 
-  hueRB = RBCreate(NULL, hsvF,  7, 153, "1",
+  hueRB = RBCreate(NULL, hsvF,  7 * dpiMult, 153 * dpiMult, "1",
 		   infofg, infobg,hicol,locol);
-  RBCreate        (hueRB,hsvF, 47, 153, "2",
+  RBCreate        (hueRB,hsvF, 47 * dpiMult, 153 * dpiMult, "2",
 		   infofg, infobg,hicol,locol);
-  RBCreate        (hueRB,hsvF, 87, 153, "3",
+  RBCreate        (hueRB,hsvF, 87 * dpiMult, 153 * dpiMult, "3",
 		   infofg, infobg,hicol,locol);
-  RBCreate        (hueRB,hsvF,  7, 170, "4",
+  RBCreate        (hueRB,hsvF,  7 * dpiMult, 170 * dpiMult, "4",
 		   infofg, infobg,hicol,locol);
-  RBCreate        (hueRB,hsvF, 47, 170, "5",
+  RBCreate        (hueRB,hsvF, 47 * dpiMult, 170 * dpiMult, "5",
 		   infofg, infobg,hicol,locol);
-  RBCreate        (hueRB,hsvF, 87, 170, "6",
+  RBCreate        (hueRB,hsvF, 87 * dpiMult, 170 * dpiMult, "6",
 		   infofg, infobg,hicol,locol);
 
-  BTCreate(&hueclrB, hsvF, 127, 158, 70, BUTTH, "Reset",
+  BTCreate(&hueclrB, hsvF, 127 * dpiMult, 158 * dpiMult, 70 * dpiMult, BUTTH, "Reset",
 	   infofg, infobg,hicol,locol);
 
   initHmap();
@@ -384,20 +382,20 @@ void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
   build_hremap();
 
   InitGraf(&intGraf);
-  CreateGraf(&intGraf, hsvF, 20, 339, infofg, infobg, "Intensity");
+  CreateGraf(&intGraf, hsvF, 20 * dpiMult, 339 * dpiMult, infofg, infobg, "Intensity");
 
 
   /********* RGB color correction doo-wahs ***********/
 
 
   InitGraf(&rGraf);
-  CreateGraf(&rGraf, rgbF, 10, 20, infofg, infobg, "Red");
+  CreateGraf(&rGraf, rgbF, 10 * dpiMult, 20 * dpiMult, infofg, infobg, "Red");
 
   InitGraf(&gGraf);
-  CreateGraf(&gGraf, rgbF, 10, 179, infofg, infobg, "Green");
+  CreateGraf(&gGraf, rgbF, 10 * dpiMult, 179 * dpiMult, infofg, infobg, "Green");
 
   InitGraf(&bGraf);
-  CreateGraf(&bGraf, rgbF, 10, 338, infofg, infobg, "Blue");
+  CreateGraf(&bGraf, rgbF, 10 * dpiMult, 338 * dpiMult, infofg, infobg, "Blue");
 
   satDial.drawobj = dragGamma;
   intGraf.drawobj = rGraf.drawobj = gGraf.drawobj = bGraf.drawobj = dragGamma;
@@ -484,8 +482,7 @@ void CreateGam(geom, gam, rgam, ggam, bgam, defpreset)
 
 
 /***************************************************/
-int GamCheckEvent(xev)
-XEvent *xev;
+int GamCheckEvent(XEvent *xev)
 {
   /* check event to see if it's for one of our subwindows.  If it is,
      deal accordingly, and return '1'.  Otherwise, return '0' */
@@ -709,7 +706,7 @@ XEvent *xev;
 
 
 /***************************************************/
-static void computeHSVlinear()
+static void computeHSVlinear(void)
 {
   /* determine linearity of HSV controls to avoid semi-expensive (and
      error-inducing) HSV calculations */
@@ -732,7 +729,7 @@ static void computeHSVlinear()
 
 
 /***************************************************/
-static void changedGam()
+static void changedGam(void)
 {
   /* called whenever an HSV/RGB gamma ctrl has changed
      applies change to image if autoCB.val is set */
@@ -744,8 +741,7 @@ static void changedGam()
 
 
 /***************************************************/
-void GamBox(vis)
-int vis;
+void GamBox(int vis)
 {
   if (vis) XMapRaised(theDisp, gamW);
   else     XUnmapWindow(theDisp, gamW);
@@ -755,24 +751,22 @@ int vis;
 
 
 /***************************************************/
-static void drawGam(x,y,w,h)
-int x,y,w,h;
+static void drawGam(int x, int y, int w, int h)
 {
   XRectangle xr;
 
   xr.x = x;  xr.y = y;  xr.width = w;  xr.height = h;
   XSetClipRectangles(theDisp, theGC, 0,0, &xr, 1, Unsorted);
 
-  drawArrow(232,178);
-  drawArrow(457,178);
+  drawArrow(232 * dpiMult, 178 * dpiMult);
+  drawArrow(457 * dpiMult, 178 * dpiMult);
 
   XSetClipMask(theDisp, theGC, None);
 }
 
 
 /***************************************************/
-static void drawBut(x,y,w,h)
-int x,y,w,h;
+static void drawBut(int x, int y, int w, int h)
 {
   int i;
   XRectangle xr;
@@ -789,19 +783,18 @@ int x,y,w,h;
 
 
 /***************************************************/
-static void drawArrow(x,y)
-int x,y;
+static void drawArrow(int x, int y)
 {
   XPoint pts[8];
 
-  pts[0].x = x+10;     pts[0].y = y;
-  pts[1].x = x-4;      pts[1].y = y-100;
-  pts[2].x = x-4;      pts[2].y = y-40;
-  pts[3].x = x-10;     pts[3].y = y-40;
-  pts[4].x = x-10;     pts[4].y = y+40;
-  pts[5].x = x-4;      pts[5].y = y+40;
-  pts[6].x = x-4;      pts[6].y = y+100;
-  pts[7].x = pts[0].x; pts[7].y = pts[0].y;
+  pts[0].x = x + 10 * dpiMult;  pts[0].y = y;
+  pts[1].x = x -  4 * dpiMult;  pts[1].y = y - 100 * dpiMult;
+  pts[2].x = x -  4 * dpiMult;  pts[2].y = y -  40 * dpiMult;
+  pts[3].x = x - 10 * dpiMult;  pts[3].y = y -  40 * dpiMult;
+  pts[4].x = x - 10 * dpiMult;  pts[4].y = y +  40 * dpiMult;
+  pts[5].x = x -  4 * dpiMult;  pts[5].y = y +  40 * dpiMult;
+  pts[6].x = x -  4 * dpiMult;  pts[6].y = y + 100 * dpiMult;
+  pts[7].x = pts[0].x;          pts[7].y = pts[0].y;
 
   XSetForeground(theDisp, theGC, infobg);
   XFillPolygon(theDisp, gamW, theGC, pts, 8, Convex, CoordModeOrigin);
@@ -811,7 +804,7 @@ int x,y;
 
 
 /***************************************************/
-static void drawCmap()
+static void drawCmap(void)
 {
   int i;
 
@@ -831,7 +824,7 @@ static void drawCmap()
 
 
 /***************************************************/
-void NewCMap()
+void NewCMap(void)
 {
   /* called when we've loaded a new picture */
 
@@ -864,7 +857,7 @@ void NewCMap()
 
 
 /***************************************************/
-void RedrawCMap()
+void RedrawCMap(void)
 {
   int i;
 
@@ -894,21 +887,20 @@ void RedrawCMap()
     y = CMAPY + (i/16)*CMAPCH;
 
     XSetForeground(theDisp, theGC, cols[i]);
-    XFillRectangle(theDisp, cmapF, theGC, x+1, y+1, CMAPCW-1,CMAPCH-1);
+    XFillRectangle(theDisp, cmapF, theGC, x+1*dpiMult, y+1*dpiMult, CMAPCW-1*dpiMult,CMAPCH-1*dpiMult);
 
     if (i == editColor || (curgroup && (cellgroup[i]==curgroup))) {
       XSetForeground(theDisp, theGC, infobg);
-      XDrawRectangle(theDisp, cmapF, theGC, x+1, y+1, CMAPCW-2,CMAPCH-2);
+      XDrawRectangle(theDisp, cmapF, theGC, x+1*dpiMult, y+1*dpiMult, CMAPCW-2*dpiMult,CMAPCH-2*dpiMult);
       XSetForeground(theDisp, theGC, infofg);
-      XDrawRectangle(theDisp, cmapF, theGC, x+2, y+2, CMAPCW-4,CMAPCH-4);
+      XDrawRectangle(theDisp, cmapF, theGC, x+2*dpiMult, y+2*dpiMult, CMAPCW-4*dpiMult,CMAPCH-4*dpiMult);
     }
   }
 }
 
 
 /***************************************************/
-static void selectCell(cellno, sel)
-int cellno, sel;
+static void selectCell(int cellno, int sel)
 {
   int x,y;
 
@@ -919,20 +911,19 @@ int cellno, sel;
 
   if (!sel) {   /* unhighlight a cell */
     XSetForeground(theDisp, theGC, cols[cellno]);
-    XFillRectangle(theDisp, cmapF, theGC, x+1, y+1, CMAPCW-1,CMAPCH-1);
+    XFillRectangle(theDisp, cmapF, theGC, x+1*dpiMult, y+1*dpiMult, CMAPCW-1*dpiMult,CMAPCH-1*dpiMult);
   }
   else {  /* highlight a cell */
     XSetForeground(theDisp, theGC, infobg);
-    XDrawRectangle(theDisp, cmapF, theGC, x+1, y+1, CMAPCW-2,CMAPCH-2);
+    XDrawRectangle(theDisp, cmapF, theGC, x+1*dpiMult, y+1*dpiMult, CMAPCW-2*dpiMult,CMAPCH-2*dpiMult);
     XSetForeground(theDisp, theGC, infofg);
-    XDrawRectangle(theDisp, cmapF, theGC, x+2, y+2, CMAPCW-4,CMAPCH-4);
+    XDrawRectangle(theDisp, cmapF, theGC, x+2*dpiMult, y+2*dpiMult, CMAPCW-4*dpiMult,CMAPCH-4*dpiMult);
   }
 }
 
 
 /***************************************************/
-static void clickGam(x,y)
-int x,y;
+static void clickGam(int x, int y)
 {
   int i;
   BUTT *bp;
@@ -958,8 +949,7 @@ int x,y;
 
 
 /***************************************************/
-static void clickCmap(x,y,but)
-int x,y,but;
+static void clickCmap(int x, int y, int but)
 {
   int i, recolor;
   BUTT *bp;
@@ -1055,7 +1045,7 @@ int x,y,but;
 
 
     else if (but==3) { /* add/delete cell(s) from current group */
-      int lastcell,j,resetdel,curcell;
+      int lastcell,resetdel,curcell;
 
       /* better save the current cmap state, as it might change */
       saveCMap(&tmpcmap);
@@ -1068,8 +1058,8 @@ int x,y,but;
 
 	lastcell = curcell;
 
-	j = XGrabPointer(theDisp, cmapF, False, 0, GrabModeAsync,
-			 GrabModeAsync, None, None, (Time) CurrentTime);
+	XV_UNUSED_RETURN(XGrabPointer(theDisp, cmapF, False, 0, GrabModeAsync,
+				GrabModeAsync, None, None, (Time) CurrentTime));
 	while (1) {
 	  Window       rW,cW;
 	  int          rx,ry,x,y;
@@ -1129,8 +1119,7 @@ int x,y,but;
 
 
 /***************************************************/
-static int deladdCell(cnum, first)
-int cnum, first;
+static int deladdCell(int cnum, int first)
 {
   int i,j,rv;
   static int mode;
@@ -1252,8 +1241,7 @@ int cnum, first;
 
 
 /*********************/
-void ChangeEC(num)
-int num;
+void ChangeEC(int num)
 {
   /* given a color # that is to become the new editColor, do all
      highlighting/unhighlighting, copy editColor's rgb values to
@@ -1305,7 +1293,7 @@ int num;
 
 
 /*********************/
-void ApplyECctrls()
+void ApplyECctrls(void)
 {
   /* sets values of {r,g,b}cmap[editColor] based on dial settings */
 
@@ -1326,7 +1314,7 @@ void ApplyECctrls()
 
 
 /*********************/
-void GenerateFSGamma()
+void GenerateFSGamma(void)
 {
   /* this function generates the Floyd-Steinberg gamma curve (fsgamcr)
 
@@ -1356,8 +1344,7 @@ void GenerateFSGamma()
 
 
 /*********************/
-static void doCmd(cmd)
-int cmd;
+static void doCmd(int cmd)
 {
   int i;
   GRAF_STATE gs;
@@ -1554,7 +1541,7 @@ int cmd;
 
 
 /*********************/
-static void SetHSVmode()
+static void SetHSVmode(void)
 {
   if (!hsvmode) {
     rhDial.title = "Red";
@@ -1593,8 +1580,7 @@ static void SetHSVmode()
 
 
 /*********************/
-static void applyGamma(cmapchange)
-     int cmapchange;
+static void applyGamma(int cmapchange)
 {
   /* called to regenerate the image based on r/g/bcmap or output of rgb/hsv
      filters.  Doesn't check autoCB.  Note: if cmap change, and we have
@@ -1677,8 +1663,7 @@ static void applyGamma(cmapchange)
 
 
 /*********************/
-static void calcHistEQ(histeq, rminv, rmaxv)
-     int *histeq, *rminv, *rmaxv;
+static void calcHistEQ(int *histeq, int *rminv, int *rmaxv)
 {
   int i, maxv, topbin, hist[256], rgb[256];
   byte *ep;
@@ -1759,7 +1744,7 @@ static void calcHistEQ(histeq, rminv, rmaxv)
 
 
 /*********************/
-void DoHistEq()
+void DoHistEq(void)
 {
   int i, histeq[256], minv, maxv;
 
@@ -1783,7 +1768,7 @@ void DoHistEq()
 
 
 /*********************/
-void DoNorm()
+void DoNorm(void)
 {
   int i, minv, maxv, v;
   GRAF_STATE gs;
@@ -1823,7 +1808,7 @@ void DoNorm()
 
 
 /*********************/
-void GammifyColors()
+void GammifyColors(void)
 {
   int i;
 
@@ -1848,8 +1833,7 @@ void GammifyColors()
 #define NOHUE -1
 
 /*********************/
-void Gammify1(col)
-int col;
+void Gammify1(int col)
 {
   int rv, gv, bv, vi, hi;
   double h,s,v;
@@ -1913,9 +1897,7 @@ int col;
 
 
 /*********************/
-void rgb2hsv(r,g,b, hr, sr, vr)
-int r, g, b;
-double *hr, *sr, *vr;
+void rgb2hsv(int r, int g, int b, double *hr, double *sr, double *vr)
 {
   double rd, gd, bd, h, s, v, max, min, del, rc, gc, bc;
 
@@ -1957,9 +1939,7 @@ double *hr, *sr, *vr;
 
 
 /*********************/
-void hsv2rgb(h, s, v, rr, gr, br)
-double h, s, v;
-int *rr, *gr, *br;
+void hsv2rgb(double h, double s, double v, int *rr, int *gr, int *br)
 {
   int    j;
   double rd, gd, bd;
@@ -1996,8 +1976,7 @@ int *rr, *gr, *br;
 
 
 /*********************/
-static void ctrls2gamstate(gs)
-     struct gamstate *gs;
+static void ctrls2gamstate(struct gamstate *gs)
 {
   xvbcopy((char *) hmap, (char *) gs->hmap, sizeof(hmap));
 
@@ -2016,8 +1995,7 @@ static void ctrls2gamstate(gs)
 
 
 /*********************/
-static void gamstate2ctrls(gs)
-struct gamstate *gs;
+static void gamstate2ctrls(struct gamstate *gs)
 {
   int changed = 0;
   struct hmap *hm;
@@ -2081,7 +2059,7 @@ struct gamstate *gs;
 static int nosave_kludge = 0;
 
 /*********************/
-static void saveGamState()
+static void saveGamState(void)
 {
   /* increment uptr, sticks current state into uptr
      set utail = uptr
@@ -2102,7 +2080,7 @@ static void saveGamState()
 
 
 /*********************/
-static void gamUndo()
+static void gamUndo(void)
 {
   /* if uptr!=uhead  decements uptr, restores state pointed to by uptr
                      if uptr now == uhead, turn off 'Undo' button
@@ -2121,7 +2099,7 @@ static void gamUndo()
 
 
 /*********************/
-static void gamRedo()
+static void gamRedo(void)
 {
   /* if uptr != utail   increments uptr, restores state pointed to by uptr
                         if uptr now == utail, turn off 'Redo' button */
@@ -2140,7 +2118,7 @@ static void gamRedo()
 
 
 /*********************/
-static void rndCols()
+static void rndCols(void)
 {
   int i,j;
 
@@ -2166,8 +2144,7 @@ static void rndCols()
 
 
 /*********************/
-static void saveCMap(cst)
-struct cmapstate *cst;
+static void saveCMap(struct cmapstate *cst)
 {
   int i;
 
@@ -2185,8 +2162,7 @@ struct cmapstate *cst;
 
 
 /*********************/
-static void restoreCMap(cst)
-struct cmapstate *cst;
+static void restoreCMap(struct cmapstate *cst)
 {
   int i;
 
@@ -2206,9 +2182,9 @@ struct cmapstate *cst;
 
 
 /*********************/
-static void parseResources()
+static void parseResources(void)
 {
-  char gname[80], tmp[80], tmp1[256];
+  char gname[80], tmp[512], tmp1[256];
   int  i,j;
   struct gamstate *gsp, gs;
 
@@ -2312,10 +2288,10 @@ static void parseResources()
 
 
 /*********************/
-static void makeResources()
+static void makeResources(void)
 {
   char rsrc[2000];     /* wild over-estimation */
-  char gname[40], rname[64], tmp[256], tmp1[256];
+  char gname[40], rname[64], tmp[512], tmp1[256];
   struct gamstate gstate;
   int i;
 
@@ -2375,7 +2351,7 @@ static void makeResources()
 
 
 /*****************************/
-static void dragGamma ()
+static void dragGamma (void)
 {
   /* called through DIAL.drawobj and GRAF.drawobj
      while gamma ctrls are being dragged
@@ -2390,7 +2366,7 @@ static void dragGamma ()
 
 
 /*****************************/
-static void dragHueDial()
+static void dragHueDial(void)
 {
   /* called through HDIAL.drawobj
      while hue gamma ctrls are being dragged
@@ -2407,7 +2383,7 @@ static void dragHueDial()
 
 
 /*****************************/
-static void dragEditColor()
+static void dragEditColor(void)
 {
   /* called through DIAL.drawobj
      while color editor ctrls are being dragged
@@ -2434,12 +2410,7 @@ static Pixmap hdbpix2[N_HDBUTT2];
 #define PH 15
 
 /**************************************************/
-static void HDCreate(hd, win, x, y, r, st, en, ccwise, str, fg, bg)
-     HDIAL      *hd;
-     Window      win;
-     int         x, y, r, st, en, ccwise;
-     const char *str;
-     u_long      fg, bg;
+static void HDCreate(HDIAL *hd, Window win, int x, int y, int r, int st, int en, int ccwise, const char *str, u_long fg, u_long bg)
 {
   int i;
 
@@ -2474,11 +2445,11 @@ static void HDCreate(hd, win, x, y, r, st, en, ccwise, str, fg, bg)
 #define BCOLS fg,bg,hicol,locol
 
   if (hd->range) {
-    BTCreate(&hd->hdbutt[HDB_ROTL], win, x-50,y+60,18,18,NULL, BCOLS);
-    BTCreate(&hd->hdbutt[HDB_ROTR], win, x-30,y+60,18,18,NULL, BCOLS);
-    BTCreate(&hd->hdbutt[HDB_FLIP], win, x-10,y+60,18,18,NULL, BCOLS);
-    BTCreate(&hd->hdbutt[HDB_EXPND],win, x+10,y+60,18,18,NULL, BCOLS);
-    BTCreate(&hd->hdbutt[HDB_SHRNK],win, x+30,y+60,18,18,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_ROTL], win, x-50*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_ROTR], win, x-30*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_FLIP], win, x-10*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_EXPND],win, x+10*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_SHRNK],win, x+30*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
 
     for (i=0; i<N_HDBUTT; i++) {
       hd->hdbutt[i].pix = hdbpix1[i];
@@ -2488,11 +2459,11 @@ static void HDCreate(hd, win, x, y, r, st, en, ccwise, str, fg, bg)
   }
 
   else {
-    BTCreate(&hd->hdbutt[HDB_ROTL], win, x-39,y+60,18,18,NULL, BCOLS);
-    BTCreate(&hd->hdbutt[HDB_ROTR], win, x-19,y+60,18,18,NULL, BCOLS);
-    BTCreate(&hd->hdbutt[HDB_DESAT],win, x+1, y+60,18,18,NULL, BCOLS);
-    BTCreate(&hd->hdbutt[HDB_SAT],  win, x+21,y+60,18,18,NULL, BCOLS);
-    CBCreate(&hd->enabCB, win, x+23, y-44, "", BCOLS);
+    BTCreate(&hd->hdbutt[HDB_ROTL], win, x-39*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_ROTR], win, x-19*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_DESAT],win, x+1*dpiMult, y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    BTCreate(&hd->hdbutt[HDB_SAT],  win, x+21*dpiMult,y+60*dpiMult,18*dpiMult,18*dpiMult,NULL, BCOLS);
+    CBCreate(&hd->enabCB, win, x+23*dpiMult, y-44*dpiMult, "", BCOLS);
     hd->enabCB.val = 1;
 
     for (i=0; i<N_HDBUTT2; i++) {
@@ -2506,9 +2477,7 @@ static void HDCreate(hd, win, x, y, r, st, en, ccwise, str, fg, bg)
 
 
 /**************************************************/
-static void HDRedraw(hd, flags)
-HDIAL *hd;
-int flags;
+static void HDRedraw(HDIAL *hd, int flags)
 {
   int    i, x, y, x1, y1;
   double a;
@@ -2662,14 +2631,14 @@ int flags;
 
     XDrawImageString(theDisp, hd->win, theGC,
 		     hd->x - XTextWidth(monofinfo, vstr, (int) strlen(vstr))/2,
-		     hd->y + HD_RADIUS + 24, vstr, (int) strlen(vstr));
+		     hd->y + HD_RADIUS + 24*dpiMult, vstr, (int) strlen(vstr));
     XSetFont(theDisp, theGC, mfont);
   }
 
 
   if (flags & HD_TITLE) {
     XSetForeground(theDisp, theGC, hd->fg);
-    ULineString(hd->win, hd->x - HD_RADIUS - 15, hd->y - HD_RADIUS - 4,
+    ULineString(hd->win, hd->x - HD_RADIUS - 15*dpiMult, hd->y - HD_RADIUS - 4*dpiMult,
 		hd->str);
   }
 
@@ -2686,8 +2655,8 @@ int flags;
 
   if (!hd->range && !hd->enabCB.val) {  /* draw dimmed */
     XSync(theDisp, False);
-    DimRect(hd->win, hd->x-HD_RADIUS-15, hd->y-HD_RADIUS-4-ASCENT,
-	    (u_int) 2*HD_RADIUS+30, (u_int) (2*HD_RADIUS+4+ASCENT+80), hd->bg);
+    DimRect(hd->win, hd->x-HD_RADIUS-15*dpiMult, hd->y-HD_RADIUS-4*dpiMult-ASCENT,
+	    (u_int) 2*HD_RADIUS+30*dpiMult, (u_int) (2*HD_RADIUS+4*dpiMult+ASCENT+80*dpiMult), hd->bg);
     XSync(theDisp, False);
     CBRedraw(&hd->enabCB);
   }
@@ -2696,9 +2665,7 @@ int flags;
 
 
 /**************************************************/
-static int HDClick(hd,mx,my)
-HDIAL *hd;
-int mx, my;
+static int HDClick(HDIAL *hd, int mx, int my)
 {
   /* called when a click received.  checks whether HDTrack needs to be
      called.  Returns '1' if click is in HD dial area, 0 otherwise */
@@ -2843,9 +2810,7 @@ int mx, my;
 
 
 /**************************************************/
-static int HDTrack(hd,mx,my)
-HDIAL *hd;
-int mx,my;
+static int HDTrack(HDIAL *hd, int mx, int my)
 {
   /* called when clicked in dial area.  tracks dragging handles around...
      returns '1' if anything changed */
@@ -2990,8 +2955,7 @@ int mx,my;
 
 
 /**************************************************/
-static int hdg2xdg(hdg)
-int hdg;
+static int hdg2xdg(int hdg)
 {
   int xdg;
 
@@ -3004,9 +2968,7 @@ int hdg;
 
 
 /**************************************************/
-static void pol2xy(cx, cy, ang, rad, xp, yp)
-int cx, cy, rad, *xp, *yp;
-double ang;
+static void pol2xy(int cx, int cy, double ang, int rad, int *xp, int *yp)
 {
   *xp = cx + (int) (cos(ang) * (double) rad);
   *yp = cy - (int) (sin(ang) * (double) rad);
@@ -3014,9 +2976,7 @@ double ang;
 
 
 /***************************************************/
-static int computeHDval(hd, x, y)
-HDIAL *hd;
-int x, y;
+static int computeHDval(HDIAL *hd, int x, int y)
 {
   int dx, dy;
   double angle;
@@ -3046,7 +3006,7 @@ int x, y;
 
 
 /****************************************************/
-static void initHmap()
+static void initHmap(void)
 {
   int i;
   for (i=0; i<N_HMAP; i++) init1hmap(i);
@@ -3054,8 +3014,7 @@ static void initHmap()
 
 
 /****************************************************/
-static void init1hmap(i)
-int i;
+static void init1hmap(int i)
 {
   int cang, width;
 
@@ -3069,7 +3028,7 @@ int i;
 
 
 /****************************************************/
-static void dials2hmap()
+static void dials2hmap(void)
 {
   int i;
   i = RBWhich(hueRB);
@@ -3085,7 +3044,7 @@ static void dials2hmap()
 
 
 /****************************************************/
-static void hmap2dials()
+static void hmap2dials(void)
 {
   int i;
   i = RBWhich(hueRB);
@@ -3104,7 +3063,7 @@ static void hmap2dials()
 
 
 /****************************************************/
-static void build_hremap()
+static void build_hremap(void)
 {
   int i,j, st1, en1, inc1, len1, st2, en2, inc2, len2;
   int a1, a2;
@@ -3168,9 +3127,7 @@ static void build_hremap()
 
 
 /*********************/
-byte *GammifyPic24(pic24, wide, high)
-     byte *pic24;
-     int   wide,high;
+byte *GammifyPic24(byte *pic24, int wide, int high)
 {
   /* applies HSV/RGB modifications to each pixel in given 24-bit image.
      creates and returns a new picture, or NULL on failure.
@@ -3331,8 +3288,7 @@ byte *GammifyPic24(pic24, wide, high)
 
 
 /*********************/
-void GamSetAutoApply(val)
-     int val;
+void GamSetAutoApply(int val)
 {
   /* turns auto apply checkbox on/off.  If val == -1, sets to 'default' val */
 
